==> eisp-mdm-0.0.8-RELEASE.jar: com/biz/eisp/mdm/org/sql/TmOrgDao_findTmOrgByAllPossible.sql <==
SELECT * FROM TM_ORG TR WHERE TR.ENABLE_STATUS=0
<#if queryTmOrgVo.id ?exists&&queryTmOrgVo.id ?length gt 0>
	AND TR.ID = '${queryTmOrgVo.id}'
</#if>
<#if queryTmOrgVo.orgName ?exists&&queryTmOrgVo.orgName ?length gt 0>
	AND TR.ORG_NAME LIKE '%${queryTmOrgVo.orgName}%'
</#if>
<#if queryTmOrgVo.orgCode ?exists&&queryTmOrgVo.orgCode ?length gt 0>
	AND TR.ORG_CODE LIKE '%${queryTmOrgVo.orgCode}%'
</#if>
<#if queryTmOrgVo.parentOrgId ?exists&&queryTmOrgVo.parentOrgId ?length gt 0>
	AND TR.ID IN (SELECT PAREN_ID FROM TM_ORG WHERE ID='${queryTmOrgVo.parentOrgId}')
</#if>
<#if queryTmOrgVo.levelOrgId ?exists&&queryTmOrgVo.levelOrgId ?length gt 0>
	AND TR.PARENT_ID = '${queryTmOrgVo.levelOrgId}'
</#if>
<#if queryTmOrgVo.orgType ?exists&&queryTmOrgVo.orgType ?length gt 0>
	AND TR.ORG_TYPE = '${queryTmOrgVo.orgType}'
</#if>
<#if queryTmOrgVo.userId ?exists&&queryTmOrgVo.userId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG
		JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID
		JOIN TM_R_USER_POSITION TUP ON TUP.POSITION_ID=TP.ID
		JOIN TM_USER TU ON TU.ID=TUP.USER_ID
		WHERE TU.ID='${queryTmOrgVo.userId}'
	) 
</#if>
<#if queryTmOrgVo.userName ?exists&&queryTmOrgVo.userName ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG
		JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID
		JOIN TM_R_USER_POSITION TUP ON TUP.POSITION_ID=TP.ID
		JOIN TM_USER TU ON TU.ID=TUP.USER_ID
		WHERE TU.USERNAME LIKE '%${queryTmOrgVo.userName}%'
	) 
</#if>
<#if queryTmOrgVo.parentAllOrgId ?exists&&queryTmOrgVo.parentAllOrgId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG START WITH TG.ID='${queryTmOrgVo.parentAllOrgId}' CONNECT BY PRIOR TG.PARENT_ID=TG.ID
	) 
</#if>
<#if queryTmOrgVo.levelAllOrgId ?exists&&queryTmOrgVo.levelAllOrgId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG START WITH TG.ID='${queryTmOrgVo.levelAllOrgId}' CONNECT BY PRIOR TG.ID=TG.PARENT_ID
	) 
</#if>
<#if queryTmOrgVo.positionName ?exists&&queryTmOrgVo.positionName ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID WHERE TP.POSITION_NAME LIKE '%${queryTmOrgVo.positionName}%'
	) 
</#if>
<#if queryTmOrgVo.positionId ?exists&&queryTmOrgVo.positionId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID WHERE TP.ID = '${queryTmOrgVo.positionId}'
	) 
</#if>

==> eisp-mdm-1.0.2-RELEASE.jar: com/biz/eisp/mdm/org/sql/TmOrgDao_findTmOrgByAllPossible.sql <==
SELECT * FROM TM_ORG TR WHERE TR.ENABLE_STATUS=0
<#if queryTmOrgVo.id ?exists&&queryTmOrgVo.id ?length gt 0>
	AND TR.ID = '${queryTmOrgVo.id}'
</#if>
<#if queryTmOrgVo.orgName ?exists&&queryTmOrgVo.orgName ?length gt 0>
	AND TR.ORG_NAME LIKE '%${queryTmOrgVo.orgName}%'
</#if>
<#if queryTmOrgVo.orgCode ?exists&&queryTmOrgVo.orgCode ?length gt 0>
	AND TR.ORG_CODE LIKE '%${queryTmOrgVo.orgCode}%'
</#if>
<#if queryTmOrgVo.parentOrgId ?exists&&queryTmOrgVo.parentOrgId ?length gt 0>
	AND TR.ID IN (SELECT PAREN_ID FROM TM_ORG WHERE ID='${queryTmOrgVo.parentOrgId}')
</#if>
<#if queryTmOrgVo.levelOrgId ?exists&&queryTmOrgVo.levelOrgId ?length gt 0>
	AND TR.PARENT_ID = '${queryTmOrgVo.levelOrgId}'
</#if>
<#if queryTmOrgVo.orgType ?exists&&queryTmOrgVo.orgType ?length gt 0>
	AND TR.ORG_TYPE = '${queryTmOrgVo.orgType}'
</#if>
<#if queryTmOrgVo.orgTypeIn ?exists&&queryTmOrgVo.orgTypeIn ?length gt 0>
	AND TR.ORG_TYPE in (${queryTmOrgVo.orgTypeIn})
</#if>
<#if queryTmOrgVo.userId ?exists&&queryTmOrgVo.userId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG
		JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID
		JOIN TM_R_USER_POSITION TUP ON TUP.POSITION_ID=TP.ID
		JOIN TM_USER TU ON TU.ID=TUP.USER_ID
		WHERE TU.ID='${queryTmOrgVo.userId}'
	) 
</#if>
<#if queryTmOrgVo.userName ?exists&&queryTmOrgVo.userName ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG
		JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID
		JOIN TM_R_USER_POSITION TUP ON TUP.POSITION_ID=TP.ID
		JOIN TM_USER TU ON TU.ID=TUP.USER_ID
		WHERE TU.USERNAME LIKE '%${queryTmOrgVo.userName}%'
	) 
</#if>
<#if queryTmOrgVo.parentAllOrgId ?exists&&queryTmOrgVo.parentAllOrgId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG START WITH TG.ID='${queryTmOrgVo.parentAllOrgId}' CONNECT BY PRIOR TG.PARENT_ID=TG.ID
	) 
</#if>
<#if queryTmOrgVo.levelAllOrgId ?exists&&queryTmOrgVo.levelAllOrgId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG START WITH TG.ID='${queryTmOrgVo.levelAllOrgId}' CONNECT BY PRIOR TG.ID=TG.PARENT_ID
	) 
</#if>
<#if queryTmOrgVo.positionName ?exists&&queryTmOrgVo.positionName ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID WHERE TP.POSITION_NAME LIKE '%${queryTmOrgVo.positionName}%'
	) 
</#if>
<#if queryTmOrgVo.positionId ?exists&&queryTmOrgVo.positionId ?length gt 0>
	AND TR.ID IN(
		SELECT TG.ID FROM TM_ORG TG JOIN TM_POSITION TP ON TG.ID=TP.ORG_ID WHERE TP.ID = '${queryTmOrgVo.positionId}'
	) 
</#if>
